/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { CfnDataSource } from 'aws-cdk-lib/aws-bedrock';
export interface HierarchicalChunkingProps {
    /**
     * The overlap tokens between adjacent chunks.
     */
    readonly overlapTokens: number;
    /**
     * Maximum number of tokens that a parent chunk can contain.
     * Keep in mind the maximum chunk size depends on the embedding model chosen.
     */
    readonly maxParentTokenSize: number;
    /**
     * Maximum number of tokens that a child chunk can contain.
     * Keep in mind the maximum chunk size depends on the embedding model chosen.
     */
    readonly maxChildTokenSize: number;
}
export declare abstract class ChunkingStrategy {
    /**
     * Fixed Sized Chunking with the default chunk size of 300 tokens and 20% overlap.
     */
    static readonly DEFAULT: ChunkingStrategy;
    /**
     * Fixed Sized Chunking with the default chunk size of 300 tokens and 20% overlap.
     * You can adjust these values based on your specific requirements using the
     * `ChunkingStrategy.fixedSize(params)` method.
     */
    static readonly FIXED_SIZE: ChunkingStrategy;
    /**
     * Hierarchical Chunking with the default for Cohere Models.
     * - Overlap tokens: 30
     * - Max parent token size: 500
     * - Max child token size: 100
     */
    static readonly HIERARCHICAL_COHERE: ChunkingStrategy;
    /**
     * Hierarchical Chunking with the default for Titan Models.
     * - Overlap tokens: 60
     * - Max parent token size: 1500
     * - Max child token size: 300
     */
    static readonly HIERARCHICAL_TITAN: ChunkingStrategy;
    /**
     * Semantic Chunking with the default of bufferSize: 0,
     * breakpointPercentileThreshold: 95, and maxTokens: 300.
     * You can adjust these values based on your specific requirements using the
     * `ChunkingStrategy.semantic(params)` method.
     */
    static readonly SEMANTIC: ChunkingStrategy;
    /**
     * Amazon Bedrock treats each file as one chunk. Suitable for documents that
     * are already pre-processed or text split.
     */
    static readonly NONE: ChunkingStrategy;
    /** Method for customizing a fixed sized chunking strategy. */
    static fixedSize(props: CfnDataSource.FixedSizeChunkingConfigurationProperty): ChunkingStrategy;
    /**
     * Method for customizing a hierarchical chunking strategy.
     * For custom chunking, the maximum token chunk size depends on the model.
     * - Amazon Titan Text Embeddings: 8192
     * - Cohere Embed models: 512
    */
    static hierarchical(props: HierarchicalChunkingProps): ChunkingStrategy;
    /**
     * Method for customizing a semantic chunking strategy.
     * For custom chunking, the maximum token chunk size depends on the model.
     * - Amazon Titan Text Embeddings: 8192
     * - Cohere Embed models: 512
    */
    static semantic(props: CfnDataSource.SemanticChunkingConfigurationProperty): ChunkingStrategy;
    /** Method for defining a no chunking strategy. */
    private static noChunking;
    /** The CloudFormation property representation of this configuration */
    abstract configuration: CfnDataSource.ChunkingConfigurationProperty;
    private constructor();
}
